pub struct ChoiceGroupParser { /* private fields */ }Expand description
Simple XML parser for choice groups using string manipulation
This is a simplified implementation that uses string parsing instead of event-based parsing to avoid borrowing issues. It’s sufficient for the infrastructure requirements.
Implementations
Sourceimpl ChoiceGroupParser
impl ChoiceGroupParser
Sourcepub fn parse_choice_group<T: XsdChoiceGroup>(
&self,
container_element: &str,
) -> Result<T>
pub fn parse_choice_group<T: XsdChoiceGroup>( &self, container_element: &str, ) -> Result<T>
Parse a choice group element by delegating to appropriate handlers