pub fn parse_from_file<P: AsRef<Path>>(path: P) -> Result<OpenScenario>Expand description
Parse an OpenSCENARIO document from a file
Reads file into memory and then parses it as a string.
pub fn parse_from_file<P: AsRef<Path>>(path: P) -> Result<OpenScenario>Parse an OpenSCENARIO document from a file
Reads file into memory and then parses it as a string.