pub enum Value<T> {
Literal(T),
Parameter(String),
Expression(String),
}Variants
Literal(T)
A literal value known at parse time
Parameter(String)
A parameter reference that will be resolved at runtime
Expression(String)
A mathematical expression that will be evaluated at runtime
Implementations
Sourceimpl<T> Value<T>
impl<T> Value<T>
Sourcepub fn resolve(&self, params: &HashMap<String, String>) -> Result<T>
pub fn resolve(&self, params: &HashMap<String, String>) -> Result<T>
Resolve this value using the provided parameter map
Sourcepub fn as_literal(&self) -> Option<&T>
pub fn as_literal(&self) -> Option<&T>
Get the literal value if this is a literal, otherwise None
Sourcepub fn as_parameter(&self) -> Option<&str>
pub fn as_parameter(&self) -> Option<&str>
Get the parameter name if this is a parameter, otherwise None
Sourcepub fn as_expression(&self) -> Option<&str>
pub fn as_expression(&self) -> Option<&str>
Get the expression if this is an expression, otherwise None