pub struct Directory {
pub path: OSString,
}Expand description
Directory path reference for catalog files
This type represents a directory path that contains catalog files. It’s used by all catalog location types to specify where to find catalog definitions that can be referenced by scenarios.
Fields
path: OSStringPath to the directory containing catalog files
Implementations
Sourceimpl Directory
impl Directory
Sourcepub fn from_parameter(param_name: String) -> Self
pub fn from_parameter(param_name: String) -> Self
Create a Directory from a parameter reference
Sourcepub fn resolve_path(&self, params: &HashMap<String, String>) -> Result<String>
pub fn resolve_path(&self, params: &HashMap<String, String>) -> Result<String>
Get the resolved path string
Sourcepub fn validate_path(&self) -> bool
pub fn validate_path(&self) -> bool
Check if the directory path is valid (basic validation)