Type Alias Double
Source pub type Double = Value<f64>;
pub enum Double {
Literal(f64),
Parameter(String),
Expression(String),
}
A literal value known at parse time
A parameter reference that will be resolved at runtime
A mathematical expression that will be evaluated at runtime