Type Alias OSString
Source pub type OSString = Value<String>;
pub enum OSString {
Literal(String),
Parameter(String),
Expression(String),
}
A literal value known at parse time
A parameter reference that will be resolved at runtime
A mathematical expression that will be evaluated at runtime