UnsignedInt

Type Alias UnsignedInt 

pub type UnsignedInt = Value<u32>;

Aliased Type

pub enum UnsignedInt {
    Literal(u32),
    Parameter(String),
    Expression(String),
}

Variants



Literal(u32)

A literal value known at parse time



Parameter(String)

A parameter reference that will be resolved at runtime



Expression(String)

A mathematical expression that will be evaluated at runtime