Type Alias UnsignedShort
Source pub type UnsignedShort = Value<u16>;
pub enum UnsignedShort {
Literal(u16),
Parameter(String),
Expression(String),
}
A literal value known at parse time
A parameter reference that will be resolved at runtime
A mathematical expression that will be evaluated at runtime