Validate

Trait Validate 

pub trait Validate {
    // Required method
    fn validate(&self, ctx: &ValidationContext) -> Result<()>;
}
Common trait for types that support validation

This trait will be implemented by all major OpenSCENARIO types to enable comprehensive validation of scenario documents.

Required Methods

fn validate(&self, ctx: &ValidationContext) -> Result<()>

Validate this object using the provided validation context

Implementors

Source

impl<T> Validate for Value<T>