Type Alias UnsignedInt
Source pub type UnsignedInt = Value<u32>;
pub enum UnsignedInt {
Literal(u32),
Parameter(String),
Expression(String),
}
A literal value known at parse time
A parameter reference that will be resolved at runtime
A mathematical expression that will be evaluated at runtime