UnsignedShort

Type Alias UnsignedShort 

pub type UnsignedShort = Value<u16>;

Aliased Type

pub enum UnsignedShort {
    Literal(u16),
    Parameter(String),
    Expression(String),
}

Variants



Literal(u16)

A literal value known at parse time



Parameter(String)

A parameter reference that will be resolved at runtime



Expression(String)

A mathematical expression that will be evaluated at runtime