pub trait Validate {
// Required method
fn validate(&self, ctx: &ValidationContext) -> Result<()>;
}Expand description
Common trait for types that support validation
This trait will be implemented by all major OpenSCENARIO types to enable comprehensive validation of scenario documents.
Required Methods
Sourcefn validate(&self, ctx: &ValidationContext) -> Result<()>
fn validate(&self, ctx: &ValidationContext) -> Result<()>
Validate this object using the provided validation context